powered by
prints a character vector of the gases present in the dataset. This is to be used to obtain the exact names of the gases before using licoread_to_fluxible.
list_gases(df, file_type = "auto", file_type_list = c("82z", "81x", "auto"))
a character vector of the gases present in the dataset
the dataframe as imported with licoread
type of file (currently works only for 82z). If "auto" (default), the function will try to detect it by itself.
list of file types
path_82z <- system.file("extdata/82z", package = "licoread") gas_df_82z <- licoread(path_82z) list_gases(gas_df_82z)
Run the code above in your browser using DataLab