Learn R Programming

licoread (version 0.3.0)

oneobs_81x: reading a single measurement from 81x file

Description

reads a single measurement from a licor .81x file

Usage

oneobs_81x(start, end, all_obs, file)

Value

a df with 1 row with the meta data of the measurement and raw data nested

Arguments

start

line number at which the measurement starts

end

line number at which the measurement ends

all_obs

list of all the lines from the full file

file

filepath to the 81x files