to read one measurement from the 82z archive
oneobs_82z(filepath, data_file, meta_file, regex_file)a tibble with all the data and metadata from one observation (one file)
path to the 82z archive
name of the file with raw data
name of the file with meta data
regex expression matching the name of the 82z file. Here in case the user has a different than the default and for easier updates.