Learn R Programming

licoread (version 0.3.0)

read_81x_onefile: reads 81x licor file

Description

reads a .81x file with several measurements

Usage

read_81x_onefile(file)

Value

a nested tibble with the meta data from each measurements as row and the raw data nested

Arguments

file

filepath the the 81x file to read