Learn R Programming

licoread (version 0.3.0)

units_82z: to create a nested tibble with the units of data

Description

to create a nested tibble with the units of data

Usage

units_82z(filepath, data_file, data_name, filename)

Value

a tibble with the units of the variables contained in the raw data

Arguments

filepath

name and path to the 82z archive

data_file

name of the file with raw data

data_name

vector of colnames

filename

name of the 82z archive