powered by
selects the focus gas and checks the columns needed for the fluxible workflow
licoread_to_fluxible( df, focus_gas, datetime_col, id_cols = c("File Name", "Obs#"), file_type = "auto", file_type_list = c("82z", "81x", "auto") )
an unnested df with only the selected gas
input dataframe from licoread
gas to select
column containing datetime information if date and time are in two different columns, provide a character vector of the form c("date", "time")
columns to identify unique fluxes
type of file (82z or 81x). If "auto" (default), the function will try to detect it by itself.
list of file types
path_82z <- system.file("extdata/82z", package = "licoread") gas_df_82z <- licoread(path_82z) licoread_to_fluxible(gas_df_82z, "LI-7810_CH4_DRY", datetime_col = c("LI-8250_DATE", "LI-8250_TIME"))
Run the code above in your browser using DataLab