powered by
reads a .81x file with several measurements
read_81x_onefile(file)
a nested tibble with the meta data from each measurements as row and the raw data nested
filepath the the 81x file to read